# Step-by-step tutorials

## Setup

For running the examples in the tutorials you can either manually install Sockeye, its dependencies and additional
tools used or use the Dockerfile we provide, which comes with everything included.

### Either: Dockerfile

Coming soon...

<!--we provide a docker file that already includes all prerequisites for running the tutorials.
If you are using the provided Dockerfile simply skip the `Setup` section in the tutorials below.-->

### Or: Manual installation
If you do not use the provided Dockerfile you can follow the [installation instructions](../README.md#installation)
to manually install Sockeye and all dependencies. The tutorials below might have additional dependencies that
will be mentioned at the beginning of each tutorial.

## Tutorials

Below is the full list of tutorials we provide. We recommend going through them in order as they will gradually
introduce different concepts and parameters used for training and translation.

1. [Sequence copy task](seqcopy)
1. [WMT German to English news translation](wmt)
